@@ -11,7 +11,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct ip_mreq* multi_request = env->new_memory_stack(env, stack, sizeof(struct ip_mreq));
 
-  void* obj_multi_request = env->new_pointer_by_name(env, stack, "Sys::Socket::Ip_mreq", multi_request, &e, __func__, FILE_NAME, __LINE__);
+  void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq", multi_request, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_multi_request;
@@ -47,7 +47,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* sta
   struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
   *address_ret = address;
 
-  void* obj_address_ret = env->new_pointer_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_address_ret;
@@ -82,7 +82,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_interface(SPVM_ENV* env, SPVM_VALUE* sta
   struct in_addr* imr_interface_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
   *imr_interface_ret = imr_interface;
 
-  void* obj_imr_interface_ret = env->new_pointer_by_name(env, stack, "Sys::Socket::In_addr", imr_interface_ret, &e, __func__, FILE_NAME, __LINE__);
+  void* obj_imr_interface_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", imr_interface_ret, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_imr_interface_ret;
