@@ -11,7 +11,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCKS_PER_SEC(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCKS_PER_SEC;
   return 0;
 #else
-  env->die(env, stack, "CLOCKS_PER_SEC is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCKS_PER_SEC is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -23,7 +23,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_BOOTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_BOOTTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_BOOTTIME is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_BOOTTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -35,7 +35,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_HIGHRES(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLOCK_HIGHRES;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_HIGHRES is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_HIGHRES is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -47,7 +47,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLOCK_MONOTONIC;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_MONOTONIC is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -59,7 +59,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_COARSE(SPVM_ENV* env, SPVM_VA
   stack[0].ival = CLOCK_MONOTONIC_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_COARSE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_MONOTONIC_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -71,7 +71,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_FAST(SPVM_ENV* env, SPVM_VALU
   stack[0].ival = CLOCK_MONOTONIC_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_FAST is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_MONOTONIC_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -83,7 +83,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_PRECISE(SPVM_ENV* env, SPVM_V
   stack[0].ival = CLOCK_MONOTONIC_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_PRECISE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_MONOTONIC_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -95,7 +95,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_RAW(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_MONOTONIC_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_RAW is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_MONOTONIC_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -107,7 +107,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROCESS_CPUTIME_ID(SPVM_ENV* env, SPVM_
   stack[0].ival = CLOCK_PROCESS_CPUTIME_ID;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_PROCESS_CPUTIME_ID is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_PROCESS_CPUTIME_ID is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -119,7 +119,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = CLOCK_PROF;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_PROF is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_PROF is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -131,7 +131,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_REALTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_REALTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -143,7 +143,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_COARSE(SPVM_ENV* env, SPVM_VAL
   stack[0].ival = CLOCK_REALTIME_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_COARSE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_REALTIME_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -155,7 +155,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_FAST(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_REALTIME_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_FAST is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_REALTIME_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -167,7 +167,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_PRECISE(SPVM_ENV* env, SPVM_VA
   stack[0].ival = CLOCK_REALTIME_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_PRECISE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_REALTIME_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -179,7 +179,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_RAW(SPVM_ENV* env, SPVM_VALUE*
   stack[0].ival = CLOCK_REALTIME_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_RAW is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_REALTIME_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -191,7 +191,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SECOND(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLOCK_SECOND;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_SECOND is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_SECOND is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -203,7 +203,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SOFTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_SOFTTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_SOFTTIME is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_SOFTTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -215,7 +215,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_THREAD_CPUTIME_ID(SPVM_ENV* env, SPVM_V
   stack[0].ival = CLOCK_THREAD_CPUTIME_ID;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_THREAD_CPUTIME_ID is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_THREAD_CPUTIME_ID is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -227,7 +227,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_TIMEOFDAY(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLOCK_TIMEOFDAY;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_TIMEOFDAY is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_TIMEOFDAY is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -239,7 +239,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLOCK_UPTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_UPTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -251,7 +251,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_COARSE(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_UPTIME_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_COARSE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_UPTIME_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -263,7 +263,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_FAST(SPVM_ENV* env, SPVM_VALUE*
   stack[0].ival = CLOCK_UPTIME_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_FAST is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_UPTIME_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -275,7 +275,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_PRECISE(SPVM_ENV* env, SPVM_VALU
   stack[0].ival = CLOCK_UPTIME_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_PRECISE is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_UPTIME_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -287,7 +287,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_RAW(SPVM_ENV* env, SPVM_VALUE* s
   stack[0].ival = CLOCK_UPTIME_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_RAW is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_UPTIME_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -299,7 +299,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLOCK_VIRTUAL;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_VIRTUAL is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "CLOCK_VIRTUAL is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -311,7 +311,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = ITIMER_PROF;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_PROF is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "ITIMER_PROF is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -323,7 +323,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REAL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = ITIMER_REAL;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_REAL is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "ITIMER_REAL is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -335,7 +335,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REALPROF(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = ITIMER_REALPROF;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_REALPROF is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "ITIMER_REALPROF is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -347,7 +347,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = ITIMER_VIRTUAL;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_VIRTUAL is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "ITIMER_VIRTUAL is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -359,7 +359,7 @@ int32_t SPVM__Sys__Time__Constant__TIMER_ABSTIME(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TIMER_ABSTIME;
   return 0;
 #else
-  env->die(env, stack, "TIMER_ABSTIME is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "TIMER_ABSTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
