@@ -11,7 +11,7 @@ int32_t SPVM__Sys__Time__Timezone__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct timezone* st_tz = env->new_memory_stack(env, stack, sizeof(struct timezone));
   
-  void* obj_tz = env->new_pointer_by_name(env, stack, "Sys::Time::Timezone", st_tz, &e, __func__, FILE_NAME, __LINE__);
+  void* obj_tz = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timezone", st_tz, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
 
   stack[0].oval = obj_tz;
